# Generated by Django 2.2.9 on 2020-02-27 08:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('modoboa_dmarc', '0002_auto_20180124_2311'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='report',
            options={},
        ),
    ]
